@@ -148,7 +148,7 @@ class AnonymousStrategy(Strategy):
                     window.scrollTo(0, document.body.scrollHeight);
                     return document.querySelectorAll(arguments[0]).length > arguments[1];
                 ''',
-                selectors.links,
+                selectors.jobs,
                 job_links_tot)
 
             if loaded:
@@ -235,48 +235,58 @@ class AnonymousStrategy(Strategy):
         while processed < query.options.limit:
             AnonymousStrategy.__accept_cookies(driver, tag)
 
-            job_links_tot = driver.execute_script('return document.querySelectorAll(arguments[0]).length;',
-                                                  selectors.links)
+            jobs_tot = driver.execute_script('return document.querySelectorAll(arguments[0]).length;', selectors.jobs)
 
-            if job_links_tot == 0:
+            if jobs_tot == 0:
                 info(tag, 'No jobs found, skip')
                 break
 
-            info(tag, f'Found {job_links_tot} jobs')
+            info(tag, f'Found {jobs_tot} jobs')
 
             # Jobs loop
-            while job_index < job_links_tot and processed < query.options.limit:
+            while job_index < jobs_tot and processed < query.options.limit:
                 sleep(self.scraper.slow_mo)
                 tag = f'[{query.query}][{location}][{processed + 1}]'
 
-                # Extract job main fields
+                # Extract job main fields and navigate job link
                 debug(tag, 'Evaluating selectors', [
+                    selectors.jobs,
                     selectors.links,
                     selectors.companies,
                     selectors.places,
                     selectors.dates])
 
                 try:
-                    job_id, job_title, job_company, job_place, job_date = driver.execute_script(
+                    job_id, job_link, job_title, job_company, job_place, job_date = driver.execute_script(
                         '''
                             const index = arguments[0];
+                            const job = document.querySelectorAll(arguments[1])[index];
+                            const link = job.querySelector(arguments[2]);
+                            
+                            // Click job link and scroll
+                            link.scrollIntoView();
+                            link.click();
+                            const linkUrl = link.getAttribute("href");
+                            
+                            // Extract job id
                             let jobId = '';
                             
-                            // First set of selectors
-                            jobId = document.querySelectorAll(arguments[1])[index].getAttribute('data-id');
+                            // First set of selectors                            
+                            jobId = job.getAttribute('data-id');
                             
                             // Second set of selectors
                             if (!jobId) {
-                                jobId = document.querySelectorAll(arguments[2])[index]
+                                jobId = job.querySelector(arguments[2])
                                     .parentElement.getAttribute('data-entity-urn').split(':').splice(-1)[0];
                             }
                                                                                 
                             return [
                                 jobId,
-                                document.querySelectorAll(arguments[2])[index].innerText,
-                                document.querySelectorAll(arguments[3])[index].innerText,
-                                document.querySelectorAll(arguments[4])[index].innerText,
-                                document.querySelectorAll(arguments[5])[index].getAttribute('datetime')
+                                linkUrl,
+                                job.querySelector(arguments[2]).innerText,
+                                job.querySelector(arguments[3]).innerText,
+                                job.querySelector(arguments[4]).innerText,
+                                job.querySelector(arguments[5]).getAttribute('datetime')
                             ];
                         ''',
                         job_index,
@@ -286,21 +296,8 @@ class AnonymousStrategy(Strategy):
                         selectors.places,
                         selectors.dates)
 
-                    # Load job details and extract job link
-                    debug(tag, 'Evaluating selectors', [
-                        selectors.links])
-
-                    job_link = driver.execute_script(
-                        '''
-                            const linkElem = document.querySelectorAll(arguments[1])[arguments[0]];
-                            linkElem.scrollIntoView();
-                            linkElem.click();
-                            return linkElem.getAttribute("href");
-                        ''',
-                        job_index,
-                        selectors.links)
-
                     # Wait for job details to load
+                    debug(tag, f'Loading details of job {job_id}')
                     load_result = AnonymousStrategy.__load_job_details(driver, selectors, job_id)
 
                     if not load_result['success']:
@@ -308,7 +305,7 @@ class AnonymousStrategy(Strategy):
                         job_index += 1
                         continue
 
-                    # Extract
+                    # Extract description
                     debug(tag, 'Evaluating selectors', [selectors.description])
 
                     job_description, job_description_html = driver.execute_script(
@@ -392,9 +389,9 @@ class AnonymousStrategy(Strategy):
                 self.scraper.emit(Events.DATA, data)
 
                 # Try fetching more jobs
-                if processed < query.options.limit and job_index == job_links_tot:
-                    job_links_tot = driver.execute_script('return document.querySelectorAll(arguments[0]).length;',
-                                                          selectors.links)
+                if processed < query.options.limit and job_index == jobs_tot:
+                    jobs_tot = driver.execute_script('return document.querySelectorAll(arguments[0]).length;',
+                                                     selectors.jobs)
 
             # Check if we reached the limit of jobs to process
             if processed == query.options.limit:
@@ -402,7 +399,7 @@ class AnonymousStrategy(Strategy):
 
             # Check if we need to paginate
             info(tag, 'Checking for new jobs to load...')
-            load_result = AnonymousStrategy.__load_more_jobs(driver, selectors, job_links_tot)
+            load_result = AnonymousStrategy.__load_more_jobs(driver, selectors, jobs_tot)
 
             if not load_result['success']:
                 info(tag, "Couldn't find more jobs for the running query")
